# Dyu

A wrapper click script for setting up everything related to dyumnin semiconductors projects.

[![CI](https://github.com/dyumnin/dyu/actions/workflows/ci.yml/badge.svg)](https://github.com/dyumnin/dyu/actions/workflows/ci.yml)
[![CommitLint](https://github.com/dyumnin/dyu/actions/workflows/commitlint.yml/badge.svg)](https://github.com/dyumnin/dyu/actions/workflows/commitlint.yml)
[![DevContainer](https://github.com/dyumnin/dyu/actions/workflows/devcontainer.yml/badge.svg)](https://github.com/dyumnin/dyu/actions/workflows/devcontainer.yml)
[![Release](https://github.com/dyumnin/dyu/actions/workflows/release.yml/badge.svg)](https://github.com/dyumnin/dyu/actions/workflows/release.yml)
[![Renovate](https://github.com/dyumnin/dyu/actions/workflows/renovate.yml/badge.svg)](https://github.com/dyumnin/dyu/actions/workflows/renovate.yml)
[![Semantic Release](https://github.com/dyumnin/dyu/actions/workflows/semantic-release.yml/badge.svg)](https://github.com/dyumnin/dyu/actions/workflows/semantic-release.yml)
[![Coverage](https://img.shields.io/endpoint?url=https://dyumnin.github.io/dyu/_static/badges/coverage.json)](https://dyumnin.github.io/dyu/reports/coverage)
[![Release](https://img.shields.io/github/v/release/dyumnin/dyu)](https://github.com/dyumnin/dyu/releases)
[![PyPI](https://img.shields.io/pypi/v/dyu)](https://pypi.org/project/dyu/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dyu)](https://pypi.org/project/dyu/)
[![GitHub](https://img.shields.io/github/license/dyumnin/dyu)](https://github.com/dyumnin/dyu/blob/main/LICENSE)

[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm-project.org)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Conventional Commits](https://img.shields.io/badge/Conventional%20Commits-1.0.0-%23FE5196?logo=conventionalcommits&logoColor=white)](https://conventionalcommits.org)
[![Pydantic v2](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/pydantic/pydantic/5697b1e4c4a9790ece607654e6c02a160620c7e1/docs/badge/v2.json)](https://pydantic.dev)
[![Copier](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/copier-org/copier/master/img/badge/badge-grayscale-inverted-border-orange.json)](https://github.com/copier-org/copier)
[![Serious Scaffold Python](https://img.shields.io/endpoint?url=https://serious-scaffold.github.io/ss-python/_static/badges/logo.json)](https://serious-scaffold.github.io/ss-python)
[![Open in Dev Containers](https://img.shields.io/static/v1?label=Dev%20Containers&message=Open&color=blue&logo=visualstudiocode)](https://vscode.dev/redirect?url=vscode://ms-vscode-remote.remote-containers/cloneInVolume?url=https://github.com/dyumnin/dyu)

> _Dyu_ is in the **Production/Stable** phase.
> Any feedback, comments, suggestions and contributions are welcome!

## To ensure consistent development style it is necessary to adhere to rules regarding folder structure, build systems etc.
This script aims to create a unified wrapper over all templates and rules.



## 📜 License

MIT License, for more details, see the [LICENSE](https://github.com/dyumnin/dyu/blob/main/LICENSE) file.
